#!/usr/bin/python
#
# all_tests.py
# A unit test suite for mp3togo
#
# (c) Simeon Veldstra 2006  <reallifesim@gmail.com>
#
# This software is free.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You may redistribute this program under the terms of the
# GNU General Public Licence version 2
# Available in this package or at http://www.fsf.org


"""**********************************************************************
  mp3togo Unit test suite

Printing of banners can be suppressed with --no-banners
To skip the long tests use --short
To test a subset of the test modules, give their names
as arguments. 

"""

import sys, os
import unittest

test_suites = [
'test_options',
'test_tags',
'test_filelist',
'test_track',
'test_task',
'test_pool']


def main():

	printbanners = True
	longtests = True
	suite = unittest.TestSuite()
	mods = {}

	args = sys.argv[1:]
	if '--no-banners' in args:
		printbanners = False
		del args[args.index('--no-banners')]
	if '--short' in args:
		longtests = False
		del args[args.index('--short')]
	
	if args:
		load = map(lambda x: x.replace('.py', ''), args)
	else:
		load = test_suites

	print "\nloading:", 
	for mod in load:
		print mod + ',',
		try:
			mods[mod] = __import__(mod)
		except ImportError:
			print "Module %s not found" % mod
			continue
		if hasattr(mods[mod], 'short_suite') and not longtests:
			suite.addTest(mods[mod].short_suite())
		else:
			if hasattr(mods[mod], 'suite'):
				suite.addTest(mods[mod].suite())
			else:
				print "\nWarning: %s has no suite() function - doing nothing" % mod
	print 
	if printbanners:
		print __doc__
		for mod in mods.keys():
			if hasattr(mods[mod], 'banner'):
				print mods[mod].banner
		print


	# Run the tests
	print "*************************** Starting tests ***************************\n\n"
	runner = unittest.TextTestRunner(verbosity=2)
	runner.run(suite)
	print '\n'

if __name__ == "__main__":
	main()
